#include <Stepper.h>

#define DEBUG 0
#define LinksInput A2
#define RechtsInput A1
#define ButtonInput A7

#define validReading(x) (x>= 512)
#define equals(x,y) (x == y)

const int stepsPerRevolution = 200;

//right Stepper
const int dirR = 2;
const int stepR = 3;
const int sleepR = 4;

//left Stepper
const int dirL = 10;
const int stepL = 9;
const int sleepL = 8;

//to be modified
float speed = 500;

// initialize the stepper library on pins 8 through 11:
Stepper StepL(stepsPerRevolution, dirL, stepL);
Stepper StepR(stepsPerRevolution, dirR, stepR);

int stepCount = 0;  // number of steps the motor has taken


/*==============================================================================
  ________________________________Functions_______________________________________
  ==============================================================================*/


void moveDJ(int speedRPM, int n, int dir)
{

  StepL.setSpeed(speedRPM);
  StepR.setSpeed(speedRPM);

  for (int i = 0; i <= n * stepsPerRevolution; i++)
  {
    StepL.step(1 * dir);
    StepR.step(1 * dir);
  }

}



void turnL(int speedRPM, int n)
{

  StepL.setSpeed(speedRPM);
  StepR.setSpeed(speedRPM);

  for (int i = 0; i <= n * stepsPerRevolution; i++)
  {
    StepL.step(-1);
    StepR.step(1);
  }

}



void turnR(int speedRPM, int n)
{

  StepL.setSpeed(speedRPM);
  StepR.setSpeed(speedRPM);

  for (int i = 0; i <= n * stepsPerRevolution; i++)
  {
    StepL.step(1);
    StepR.step(-1);
  }

}



void checkButtonInput()
{
  int reading = analogRead(ButtonInput);

  if (reading > 512 && speed <= 2000 && reading < 2000)
  {
    speed += 250;

#ifdef DEBUG
    Serial.println("speeeddd");
#endif
  }
}

/*==============================================================================
  ____________________________________Setup_______________________________________
  ==============================================================================*/

void setup() {
  Serial.begin(9600);

  pinMode(sleepR, OUTPUT);
  pinMode(sleepL, OUTPUT);

  pinMode(LinksInput, INPUT);
  pinMode(RechtsInput, INPUT);

  digitalWrite(sleepL, HIGH);
  digitalWrite(sleepR, HIGH);

  pinMode(ButtonInput, INPUT);
}

/*==============================================================================
  ______________________________Main_Loop_________________________________________
  ==============================================================================*/

void loop() {
  moveDJ(speed, 5, 1);

#ifdef DEBUG
  Serial.println("geradeaus");
#endif

  float LinksInputV = analogRead(LinksInput);
  float RechtsInputV = analogRead(RechtsInput);
  checkButtonInput();     //reads pin value and modifies speed(+500) if input

  if (validReading(LinksInputV)) //*5 / 1023
  {
    turnR(speed, 28);
#ifdef DEBUG
    Serial.println("Rechts");
#endif
  }

  if (validReading(RechtsInputV)) // Fehler liegt hier
  {
    turnL(speed, 28);
#ifdef DEBUG
    Serial.println("Links");
#endif
  }

  if (equals(LinksInputV, RechtsInputV) && validReading(RechtsInputV) && validReading(LinksInputV) )
  {
    turnL(speed, 28);
#ifdef DEBUG
    Serial.println("Gleich");
#endif
  }

}
